package com.ruoyi.invest.service;

import com.ruoyi.invest.domain.TProjectInformation;
import com.ruoyi.invest.domain.TProjectMeeting;

import java.util.List;

/**
 * 文件资料Service接口
 * 
 * @author ruoyi
 * @date 2024-02-23
 */
public interface ITProjectInformationService 
{
    /**
     * 查询文件资料
     * 
     * @param id 文件资料主键
     * @return 文件资料
     */
    public TProjectInformation selectTProjectInformationById(String id);

    /**
     * 查询文件资料列表
     * 
     * @param tProjectInformation 文件资料
     * @return 文件资料集合
     */
    public List<TProjectInformation> selectTProjectInformationList(TProjectInformation tProjectInformation);

    /**
     * 新增文件资料
     * 
     * @param tProjectInformation 文件资料
     * @return 结果
     */
    public int insertTProjectInformation(TProjectInformation tProjectInformation);

    /**
     * 修改文件资料
     * 
     * @param tProjectInformation 文件资料
     * @return 结果
     */
    public int updateTProjectInformation(TProjectInformation tProjectInformation);

    /**
     * 批量删除文件资料
     * 
     * @param ids 需要删除的文件资料主键集合
     * @return 结果
     */
    public int deleteTProjectInformationByIds(String[] ids);

    /**
     * 删除文件资料信息
     * 
     * @param id 文件资料主键
     * @return 结果
     */
    public int deleteTProjectInformationById(String id);

    /**
     * 批量删除文件资料(修改del_flag状态)
     *
     * @param ids 需要删除的文件资料主键集合
     * @return 结果
     */
    public int updateTProjectInformationByIds(String[] ids);

    /**
     * 批量删除文件资料(修改del_flag状态)
     *
     * @param fileIds 需要删除的文件资料主键集合
     * @return 结果
     */
    public int updateTProjectInformationByFileIds(String[] fileIds);

    /**
     * 根据项目ID获取会议记录
     * @param projectPoolId
     * @return
     */
    public List<TProjectInformation> listProjectPoolId(String projectPoolId);
}
